@@ -27,6 +27,13 @@ class Cohort(models.Model):
     assigned_count = models.IntegerField()
 
 
+class Decision(models.Model):
+    academic_qtr_id = models.IntegerField()
+    display_name = models.CharField(max_length=255)
+    assigned_count = models.IntegerField()
+    decision_id = models.CharField(max_length=128)
+
+
 class Quarter(models.Model):
     id = models.IntegerField()
     begin = models.DateTimeField()
